@@ -97,7 +97,6 @@ ContactsXmlHandler::endElement (const QString & /*namespaceURI*/,
                                 const QString &localName        ,
                                 const QString & /*qName*/       )
 {
-    QString msg;
     do // Begin cleanup block (not a loop)
     {
         if (localName == "id") {
@@ -152,6 +151,8 @@ ContactsXmlHandler::endElement (const QString & /*namespaceURI*/,
 #endif
 
         countUsableContacts ++;
+
+        currInfo.hrefPhoto.replace ("%40", "@");
         emit oneContact (currInfo);
     } while (0); // End cleanup block (not a loop)
     return (true);
