@@ -183,7 +183,7 @@ MqClientThread::run ()
         }
 
         qDebug() << "Mq thread: Attempting to connect to" << strHost;
-        rv = this->mq_connect (strHost.toLatin1().constData(), port, 60, true);
+        rv = this->mq_connect (strHost.toLatin1().constData(), port, 60, false);
         if (0 != rv) {
             qWarning() << "Mq thread: Failed to connect. Error =" << rv;
             emit status ("Failed to connect to Mosquitto server");
